#!/usr/bin/env python

"""Setup script for the adns module distribution."""

import os, sys
from distutils.core import setup
from distutils.extension import Extension

# You probably don't have to do anything past this point. If you
# do, please mail me the configuration for your platform. Don't
# forget to include the value of sys.platform and os.name.

include_dirs = []
library_dirs = []
runtime_library_dirs = []
extra_objects = []

if os.name == "posix":  # most Linux/UNIX platforms
    libraries = ["adns"]
else:
    raise ValueError("sys.platform=%s, os.name=%s") % \
          (sys.platform, os.name)

long_description = \
    """adns-python is a Python module that interfaces to the adns asynchronous
    resolver library.
    
    http://www.gnu.org/software/adns/
    """
setup(  # Distribution meta-data
    name="adns",
    version="1.4.1",
    description="An interface to GNU adns - python3 port",
    author="Loic Jaquemet",
    author_email="loic.jaquemet+python@gmail.com",
    url="https://github.com/trolldbois/python3-adns/",
    download_url="https://github.com/trolldbois/python3-adns/archive/master.tar.gz",
    long_description=long_description,
    license="GPL",
    classifiers=[
        "Development Status :: 6 - Mature",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Operating System :: POSIX",
        "Topic :: Internet :: Name Service (DNS)",
        "Topic :: Software Development :: Libraries",
    ],

    # Description of the modules and packages in the distribution

    py_modules=["DNSBL", "ADNS"],

    # ext_modules = cythonize("adns.pyx"),
    ext_modules=[Extension(name='adns', sources=['adnsmodule.c'],
                           include_dirs=include_dirs, library_dirs=library_dirs,
                           runtime_library_dirs=runtime_library_dirs, libraries=libraries,
                           extra_objects=extra_objects, )],

)



#!/usr/bin/env python

"""Test functions."""

import adns

import socket
import ipaddress
import unittest


def get_ip(hostname):
    return socket.gethostbyname_ex(hostname)[2][0]


class TestADNS(unittest.TestCase):

    def setUp(self):
        self.resolver = adns.init()

    def test_synchronous(self):
        # sync
        # Results are generally returned as a 4-tuple: status, CNAME, expires, answer
        host = "google-public-dns-a.google.com."
        result = self.resolver.synchronous(host, adns.rr.A)
        self.assertEqual(result[0], 0)
        ip1 = ipaddress.ip_address(result[3][0])
        ip2 = ipaddress.ip_address(get_ip(host))
        self.assertEqual(ip1, ip2)

    # def submit(self, qname, rr, flags=0, callback=None, extra=None):

    # def submit_reverse(self, qname, rr, flags=0, callback=None, extra=None):

    # def submit_reverse_any(self, qname, rr, flags=0, callback=None, extra=None):

    # def cancel(self, query):

    # def run(self, timeout=0):

    # def finished(self):

    # def finish(self):

    # def run_max(self, max):

    # def globalsystemfailure(self):


import DNSBL


class TestDNSBL(unittest.TestCase):
    def test_dnsbl(self):
        blacklists = [
            DNSBL.DNSBL('ORDB', 'relays.ordb.org.',
                        'http://ordb.org/lookup?addr=%s',
                        {'127.0.0.2': 'ORDB'}),
            DNSBL.DNSBL('DEVNULL', 'dev.null.dk.',
                        'http://fabel.dk/relay/test/index.epl?ip=%s&send=Check',
                        {'127.0.0.2': 'DEVNULL'}),
        ]

        s = DNSBL.DNSBLQueryEngine(blacklists=blacklists)
        for i in ['8.8.8.8', '182.0.1.1']:
            s.submit_dnsbl(i)
        s.finish()
        listed = s.dnsbl_results
        self.assertEqual(len(listed), 2)
        # for k, v in list(listed.items()):
        #     hits = []
        #     for l, url in v: hits.append(l)
        #     if len(listed) > 1:
        #         print("%s: %s" % (k, ','.join(hits)))
        #     else:
        #         print(','.join(hits))


if __name__ == '__main__':
    unittest.main()
    # TestDNSBL().test_dnsbl()
